#include <iostream>
using namespace std;
#include <QApplication>
#include <unistd.h>
#include "accelManagerGUI.h"
#include "GlStatus.h"

int main(int argc, char *argv[]) {
	int uid = getuid();
	if (uid != 0) {
		cout << "You are not root. Correcting that." << endl;
		execlp("kdesu", "kdesu", "accel-manager", NULL);
	} 
	QApplication app(argc, argv);
	AccelManagerGUI manager;
	manager.show();
	return app.exec();
}